@@ -1,5 +1,5 @@
 """
-# SketchRNN
+# Sketch RNN
 
 This is an annotated implementation of the paper
 [A Neural Representation of Sketch Drawings](https://arxiv.org/abs/1704.03477).
@@ -90,7 +90,7 @@ class StrokesDataset(Dataset):
         # They represent *pen down*, *pen up* and *end-of-sequence* in that order.
         # $p_1$ is $1$ if the pen touches the paper in the next step.
         # $p_2$ is $1$ if the pen doesn't touch the paper in the next step.
-        # $p_2$ is $1$ if it is the end of the drawing.
+        # $p_3$ is $1$ if it is the end of the drawing.
         self.data = torch.zeros(len(data), longest_seq_len + 2, 5, dtype=torch.float)
         # The mask array is needs only one extra-step since it is for the outputs of the
         # decoder, which takes in `data[:-1]` and predicts next step.
@@ -236,7 +236,7 @@ class EncoderRNN(Module):
 
 class DecoderRNN(Module):
     """
-    ## Encoder module
+    ## Decoder module
 
     This consists of a LSTM
     """
@@ -656,10 +656,10 @@ def main():
         # Number of inner iterations within an epoch to switch between training, validation and sampling.
         'inner_iterations': 10
     }, 'run')
-    experiment.start()
 
-    # Run the experiment
-    configs.run()
+    with experiment.start():
+        # Run the experiment
+        configs.run()
 
 
 if __name__ == "__main__":
